#include "yocto_api.h"
#include "yocto_led.h"
#include <iostream>
#include <stdlib.h>

using namespace std;

static void usage(void)
{
  cout << "usage: demo <serial_number>  [ on | off ]" << endl;
  cout << "       demo <logical_name> [ on | off ]" << endl;
  cout << "       demo any [ on | off ] (use any discovered device)" << endl;
  u64 now = yGetTickCount();
  while (yGetTickCount() - now < 3000) {
    // wait 3 sec to show the message
  }
  exit(1);
}

int main(int argc, const char * argv[])
{
  string errmsg;
  string target;
  YLed   *led;
  string on_off;

  if(argc < 3) {
    usage();
  }
  target    = (string) argv[1];
  on_off = (string) argv[2];

  // Setup the API to use local USB devices
  if(yRegisterHub("usb", errmsg) != YAPI_SUCCESS) {
    cerr << "RegisterHub error: " << errmsg << endl;
    return 1;
  }

  if(target == "any") {
    led =  yFirstLed();
  } else {
    led =  yFindLed(target + ".led");
  }
  if (led && led->isOnline()) {
    led->set_power(on_off == "on" ? Y_POWER_ON : Y_POWER_OFF);
  } else {
    cout << "Module not connected (check identification and USB cable)" << endl;
  }
  yFreeAPI();

  return 0;
}
